@@ -47,10 +47,10 @@ from .utils import (
     normalise_svg_path,
 )
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 __license__ = 'LGPL 3'
 __author__ = 'Dinu Gherman'
-__date__ = '2020-03-22'
+__date__ = '2020-08-26'
 
 XML_NS = 'http://www.w3.org/XML/1998/namespace'
 
@@ -73,6 +73,20 @@ Box = namedtuple('Box', ['x', 'y', 'width', 'height'])
 split_whitespace = re.compile(r'[^ \t\r\n\f]+').findall
 
 
+def register_font(font_name, font_path):
+    """
+    Register a font by name or alias and path to font including file extension.
+    """
+    NOT_FOUND = (None, False)
+    if font_name not in STANDARD_FONT_NAMES and font_name not in _registered_fonts:
+        try:
+            registerFont(TTFont(font_name, font_path))
+            _registered_fonts[font_name] = True
+            return font_name, True
+        except TTFError:
+            return NOT_FOUND
+
+
 def find_font(font_name):
     """Return the font and a Boolean indicating if the match is exact."""
     if font_name in STANDARD_FONT_NAMES:
@@ -81,32 +95,29 @@ def find_font(font_name):
         return font_name, _registered_fonts[font_name]
 
     NOT_FOUND = (None, False)
+    # Try first to register the font if it exists as ttf
+    reg_name, exact = register_font(font_name, '%s.ttf' % font_name)
+    if reg_name is not None:
+        return reg_name, exact
+    # Try searching with Fontconfig
     try:
-        # Try first to register the font if it exists as ttf,
-        # based on ReportLab font search.
-        registerFont(TTFont(font_name, '%s.ttf' % font_name))
-        _registered_fonts[font_name] = True
-        return font_name, True
+        pipe = subprocess.Popen(
+            ['fc-match', '-s', '--format=%{file}\\n', font_name],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        output = pipe.communicate()[0].decode(sys.getfilesystemencoding())
+        font_path = output.split('\n')[0]
+    except OSError:
+        return NOT_FOUND
+    try:
+        registerFont(TTFont(font_name, font_path))
     except TTFError:
-        # Try searching with Fontconfig
-        try:
-            pipe = subprocess.Popen(
-                ['fc-match', '-s', '--format=%{file}\\n', font_name],
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-            )
-            output = pipe.communicate()[0].decode(sys.getfilesystemencoding())
-            font_path = output.split('\n')[0]
-        except OSError:
-            return NOT_FOUND
-        try:
-            registerFont(TTFont(font_name, font_path))
-        except TTFError:
-            return NOT_FOUND
-        # Fontconfig may return a default font totally unrelated with font_name
-        exact = font_name.lower() in os.path.basename(font_path).lower()
-        _registered_fonts[font_name] = exact
-        return font_name, exact
+        return NOT_FOUND
+    # Fontconfig may return a default font totally unrelated with font_name
+    exact = font_name.lower() in os.path.basename(font_path).lower()
+    _registered_fonts[font_name] = exact
+    return font_name, exact
 
 
 class NoStrokePath(Path):
@@ -142,6 +153,8 @@ class ClippingPath(Path):
         props = Path.getProperties(self, *args, **kwargs)
         if 'fillColor' in props:
             props['fillColor'] = None
+        if 'strokeColor' in props:
+            props['strokeColor'] = None
         return props
 
 
@@ -824,6 +837,10 @@ class SvgRenderer:
     def renderSvg(self, node, outermost=False):
         _saved_preserve_space = self.shape_converter.preserve_space
         self.shape_converter.preserve_space = node.getAttribute("{%s}space" % XML_NS) == 'preserve'
+        view_box = self.get_box(node, default_box=True)
+        _saved_box = self.attrConverter.main_box
+        if view_box:
+            self.attrConverter.set_box(view_box)
 
         # Rendering all definition nodes first.
         svg_ns = node.nsmap.get(None)
@@ -834,6 +851,7 @@ class SvgRenderer:
         for child in node.getchildren():
             self.renderNode(child, group)
         self.shape_converter.preserve_space = _saved_preserve_space
+        self.attrConverter.set_box(_saved_box)
 
         # Translating
         if not outermost:
@@ -842,7 +860,6 @@ class SvgRenderer:
                 group.translate(x or 0, y or 0)
 
         # Scaling
-        view_box = self.get_box(node)
         if not view_box and outermost:
             # Apply only the 'reverse' y-scaling (PDF 0,0 is bottom left)
             group.scale(1, -1)
@@ -982,6 +999,10 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
         x, y, width, height, rx, ry = self.convert_length_attrs(
             node, 'x', 'y', 'width', 'height', 'rx', 'ry'
         )
+        if rx > (width / 2):
+            rx = width / 2
+        if ry > (height / 2):
+            ry = height / 2
         return Rect(x, y, width, height, rx=rx, ry=ry)
 
     def convertCircle(self, node):
@@ -1401,6 +1422,14 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                     pass
         if getattr(shape, 'fillOpacity', None) is not None and shape.fillColor:
             shape.fillColor.alpha = shape.fillOpacity
+        if getattr(shape, 'strokeWidth', None) == 0:
+            # Quoting from the PDF 1.7 spec:
+            # A line width of 0 denotes the thinnest line that can be rendered at device
+            # resolution: 1 device pixel wide. However, some devices cannot reproduce 1-pixel
+            # lines, and on high-resolution devices, they are nearly invisible. Since the
+            # results of rendering such zero-width lines are device-dependent, their use
+            # is not recommended.
+            shape.strokeColor = None
 
 
 def svg2rlg(path, resolve_entities=False, **kwargs):
